#include <iostream>
#include <unordered_set>
#include <string>

struct Person {
    std::string name;
    int age;

    bool operator==(const Person& other) const {
        return name == other.name && age == other.age;
    }
};

// Custom hash function for Person
struct PersonHash {
    std::size_t operator()(const Person& p) const {
        return std::hash<std::string>()(p.name) ^ std::hash<int>()(p.age);
    }
};

int main() {
    std::unordered_set<Person, PersonHash> people = {
        {"Alice", 30},
        {"Bob", 25},
        {"Charlie", 40}
    };

    // Insertion
    people.insert({"Dave", 35});

    // Lookup
    Person searchPerson = {"Bob", 25};
    if (people.find(searchPerson) != people.end()) {
        std::cout << "Found Bob, age 25." << std::endl;
    }

    // Iterating over the set
    std::cout << "People in the set:" << std::endl;
    for (const auto& person : people) {
        std::cout << person.name << ", " << person.age << std::endl;
    }

    return 0;
}

